.. _api_climatology:

Climatologies
=============

Climatoligies are utility functions used to help in creating standard atmospheres.


MIPAS Reference Atmospheres
---------------------------

.. automodule:: sasktran2.climatology.mipas


US76 Standard Atmosphere
------------------------

.. automodule:: sasktran2.climatology.us76
